// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.register.provider.azure.action;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.junit.jupiter.MockitoExtension;
import org.opengroup.osdu.register.action.model.Filter;

import java.sql.Timestamp;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

@ExtendWith(MockitoExtension.class)
public class ActionDocTest {

    @Test
    public void shouldCreateActionDocWithAllArgsConstructor() {
        String id = "test-id";
        String name = "test-action";
        String description = "test-description";
        String img = "https://mycdn.com/img.png";
        String url = "https://myapp.osdu.opengroup.org/action/{id}/{data.project}";
        String contactEmail = "test@domain.com";
        Timestamp createdOnEpoch = new Timestamp(System.currentTimeMillis());
        Filter filter = new Filter();
        String dataPartitionId = "opendes";

        ActionDoc doc = new ActionDoc(id, name, description, img, url, contactEmail, createdOnEpoch, filter, dataPartitionId);

        assertNotNull(doc);
        assertEquals(id, doc.getId());
        assertEquals(name, doc.getName());
        assertEquals(description, doc.getDescription());
        assertEquals(img, doc.getImg());
        assertEquals(url, doc.getUrl());
        assertEquals(contactEmail, doc.getContactEmail());
        assertEquals(createdOnEpoch, doc.getCreatedOnEpoch());
        assertEquals(filter, doc.getFilter());
        assertEquals(dataPartitionId, doc.getDataPartitionId());
    }

    @Test
    public void shouldCreateActionDocWithNoArgsConstructor() {
        ActionDoc doc = new ActionDoc();
        assertNotNull(doc);
    }
}
